@@ -5,6 +5,7 @@ use cogo::std::time::time;
 fn main() {
     let mut t = Time::now();
     println!("{}", t);
+    println!("{:?}", t);
     println!("{}", t.unix());
     println!("{}", t.unix_nano());
 
@@ -16,7 +17,7 @@ fn main() {
 
     //add 1 day
     t.add(1 * 24 * Duration::from_secs(3600));
-    println!("add one day:{}", t);
+    println!("added 1 day:{}", t);
     assert_ne!(from_js, t);
 
     //is before?
@@ -30,27 +31,26 @@ fn main() {
     assert_eq!(t, parsed);
 
     //format time to str
-    let formated = t.format(time::RFC3339);
-    println!("{}", formated);
+    let formatted = t.format(time::RFC3339);
+    println!("formatted: {}", formatted);
 
-    let formated = t.format(time::RFC3339Nano);
-    println!("{}", formated);
+    let formatted = t.format(time::RFC3339Nano);
+    println!("formatted: {}", formatted);
 
-    let formated = t.format("[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]");
-    println!("{}", formated);
+    let formatted = t.format("[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]");
+    println!("formatted: {}", formatted);
 
-    let formated = t.format(time::RFC1123);
-    println!("{}", formated);
+    let formatted = t.format(time::RFC1123);
+    println!("formatted: {}", formatted);
 
-    let formated = t.utc();
-    println!("to utc: {}", formated);
-    assert_eq!(t, formated.local());
+    let formatted = t.utc();
+    println!("to utc: {}", formatted);
+    assert_eq!(t, formatted.local());
 
-    let formated = t.local();
-    println!("to local: {}", formated);
-    assert_eq!(t, formated);
+    let formatted = t.local();
+    println!("to local: {}", formatted);
+    assert_eq!(t, formatted);
 
-
-    println!("{}", Time::default());
+    println!("default(): {}", Time::default());
     assert_eq!(true, Time::default().is_zero());
 }
\ No newline at end of file
