@@ -1,10 +1,10 @@
-use std::fmt::{self, Debug, Display};
+use std::fmt::{self, Debug, Display, Formatter};
 use std::io::ErrorKind::UnexpectedEof;
 use crate::std::io::io;
 
 pub type Result<T> = std::result::Result<T, Error>;
 
-#[derive(Clone, Debug, Eq, PartialEq, Hash)]
+#[derive(Clone, Eq, PartialEq, Hash)]
 pub struct Error {
     pub inner: String,
 }
@@ -19,11 +19,16 @@ impl Error {
             inner: format!("{}{}", info, e)
         }
     }
+
+    pub fn to_string(&self) -> String {
+        self.inner.clone()
+    }
 }
 
+
 /// warp errors
 #[macro_export]
-macro_rules! err_warp {
+macro_rules! err {
      ($($arg:tt)*) => {{
          $crate::std::errors::Error{
              inner: format!($($arg)*)
@@ -43,12 +48,19 @@ pub trait FromError<T>: Sized {
     fn from_err(_: T) -> Error;
 }
 
-impl ToString for Error {
-    fn to_string(&self) -> String {
-        self.inner.clone()
+impl Display for Error {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        std::fmt::Display::fmt(&self.inner, f)
     }
 }
 
+impl Debug for Error {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        std::fmt::Debug::fmt(&self.inner, f)
+    }
+}
+
+
 impl From<std::io::Error> for Error {
     #[inline]
     fn from(err: std::io::Error) -> Self {
@@ -62,6 +74,8 @@ impl From<std::io::Error> for Error {
     }
 }
 
+impl std::error::Error for Error {}
+
 impl From<&str> for Error {
     fn from(arg: &str) -> Self {
         return new(arg.to_string());
