@@ -45,6 +45,10 @@ unsafe impl<K, V> Send for SyncMapImpl<K, V> {}
 unsafe impl<K, V> Sync for SyncMapImpl<K, V> {}
 
 impl<K, V> SyncMapImpl<K, V> where K: std::cmp::Eq + Hash + Clone {
+    pub fn new_arc() -> Arc<Self> {
+        Arc::new(Self::new())
+    }
+
     pub fn new() -> Self {
         Self {
             read: UnsafeCell::new(Map::new()),
