@@ -98,26 +98,44 @@ impl<T> MPMCBuffer<T> {
         }
     }
 
+    /// send one message. If the length limit is exceeded or chan closed, wait for the message to be consumed
     pub fn send(&self, t: T) -> Result<(), SendError<T>> {
         if self.receiver_num.load(Ordering::Acquire) == 0 {
             return Err(SendError(t));
         }
+        loop {
+            if self.buffer.len() >= self.buffer_limit {
+                self.wake_sender.wait();
+            } else {
+                break;
+            }
+        }
         self.buffer.push(t);
         self.wake_recv.post();
-        if self.buffer.len() > self.buffer_limit {
-            self.wake_sender.wait();
+        Ok(())
+    }
+
+    /// try send one message.If the length limit is exceeded or chan closed, return a error
+    pub fn try_send(&self, t: T) -> Result<(), SendError<T>> {
+        if self.receiver_num.load(Ordering::Acquire) == 0 {
+            return Err(SendError(t));
         }
+        if self.buffer.len() >= self.buffer_limit {
+            return Err(SendError(t));
+        }
+        self.buffer.push(t);
+        self.wake_recv.post();
         Ok(())
     }
 
     /// wake one sender
     #[inline]
     fn wake_sender(&self) {
-        if (self.buffer.len() + 1) > self.buffer_limit {
-            self.wake_sender.post();
-        }
+        self.wake_sender.post();
     }
 
+    /// received a message. If the message is empty, a wait is entered, and an error is returned if the channel is closed
+    /// If you want to try to receive a message, use try_recv
     pub fn recv(&self, dur: Option<Duration>) -> Result<T, RecvTimeoutError> {
         match self.try_recv() {
             Ok(data) => return Ok(data),
@@ -277,10 +295,6 @@ impl<T> Sender<T> {
     }
 }
 
-unsafe impl<T: Send> Send for Sender<T> {}
-// impl<T> !Sync for Sender<T> {}
-
-
 /// /////////////////////////////////////////////////////////////////////////////
 /// Sender
 /// /////////////////////////////////////////////////////////////////////////////
@@ -290,10 +304,16 @@ impl<T> Sender<T> {
         Sender { inner }
     }
 
+    /// send one message. If the length limit is exceeded or chan closed, wait for the message to be consumed
     pub fn send(&self, t: T) -> Result<(), SendError<T>> {
         self.inner.send(t)
     }
 
+    /// try send one message.If the length limit is exceeded or chan closed, return a error
+    pub fn try_send(&self, t: T) -> Result<(), SendError<T>> {
+        self.inner.try_send(t)
+    }
+
     /// return how many elements in the queue that are not consumed by receivers
     pub fn pressure(&self) -> usize {
         self.inner.wake_recv.get_value()
@@ -332,6 +352,8 @@ impl<T> Receiver<T> {
         self.inner.try_recv()
     }
 
+    /// received a message. If the message is empty, a wait is entered, and an error is returned if the channel is closed
+    /// If you want to try to receive a message, use try_recv
     pub fn recv(&self) -> Result<T, RecvError> {
         match self.inner.recv(None) {
             Err(RecvTimeoutError::Timeout) => unreachable!("mpmc recv timeout"),
@@ -419,6 +441,8 @@ mod tests {
     use std::sync::mpsc::{RecvTimeoutError, TryRecvError};
     use std::thread;
     use std::time::Duration;
+    use crate::coroutine::sleep;
+    use crate::std::sync::{WaitGroup};
 
     pub fn stress_factor() -> usize {
         match env::var("RUST_TEST_STRESS") {
@@ -427,6 +451,29 @@ mod tests {
         }
     }
 
+    #[test]
+    fn wait_test() {
+        let wg = WaitGroup::new();
+        let (tx, rx) = bounded::<i32>(1);
+        let wg_clone = wg.clone();
+        let result = Arc::new(std::sync::Mutex::new(Duration::from_secs(0)));
+        let result1 = result.clone();
+        go!(move ||{
+            tx.send(1);
+            drop(wg_clone);
+            let now = std::time::Instant::now();
+            tx.send(2);
+            let mut l=result1.lock().unwrap();
+            *l = now.elapsed();
+        });
+        wg.wait();
+        sleep(Duration::from_secs(2));
+        rx.recv().unwrap();
+        rx.recv().unwrap();
+        let d = result.lock().unwrap();
+        assert_eq!(d.as_secs() >= 2, true);
+    }
+
     #[test]
     fn smoke() {
         let (tx, rx) = channel::<i32>();
