@@ -167,9 +167,32 @@ impl Time {
         self.inner.nanosecond() as i32
     }
 
-    /// for example:
-    /// "[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]"
+    /// format a time to string
+    /// [year]
+    /// [month]
+    /// [ordinal]
+    /// [weekday]
+    /// [week_number]
+    /// [day]
+    /// [hour]
+    /// [minute]
+    /// [period]
+    /// [second]
+    /// [subsecond]
+    /// [offset_hour sign:mandatory]
+    /// [offset_minute]
+    /// [offset_second]
     ///
+    /// for example:
+    /// ```rust
+    ///     use cogo::std::time::Time;
+    ///
+    ///     let mut t = Time::now();
+    ///     let formatted = t.format(
+    ///     "[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]"
+    ///     );
+    ///     println!("formatted: {}", formatted);
+    /// ```
     pub fn format(&self, layout: &str) -> String {
         let f = {
             match format_description::parse(layout) {
@@ -187,9 +210,30 @@ impl Time {
         self.inner.format(&f).unwrap_or_default()
     }
 
-    /// for example:
-    /// "[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]"
+    /// parse a string value to Time。
+    /// [year]
+    /// [month]
+    /// [ordinal]
+    /// [weekday]
+    /// [week_number]
+    /// [day]
+    /// [hour]
+    /// [minute]
+    /// [period]
+    /// [second]
+    /// [subsecond]
+    /// [offset_hour sign:mandatory]
+    /// [offset_minute]
+    /// [offset_second]
     ///
+    /// for example:
+    /// ```rust
+    ///     use cogo::std::time::{RFC3339Nano,Time};
+    ///
+    ///     let parsed = Time::parse("[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]","2022-02 033 Wednesday 05-02 01:49 AM:22.1210536 +08:00:00").unwrap();
+    ///
+    ///     let parsed = Time::parse(RFC3339Nano, "2022-02-03T01:51:00.9335458+08:00").unwrap();
+    /// ```
     pub fn parse(layout: &str, value: &str) -> Result<Self> {
         match format_description::parse(layout) {
             Ok(v) => {
@@ -222,7 +266,9 @@ impl Time {
 
 impl Debug for Time {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        std::fmt::Debug::fmt(&self.inner, f)
+        f.debug_tuple("Time")
+            .field(&self.format(RFC3339Nano))
+            .finish()
     }
 }
 
